@@ -229,45 +229,54 @@ if __name__ == "__main__":
         # Expérience pour prouver que l'imputation de valeurs via SNMF
         # donne les meilleurs résultats quand on connait le nombre exact de composants
         # nb_clusters = np.random.randint(low=5, high=40)
-        nb_clusters = 12
+        nb_clusters = 10
         min_corr = np.random.uniform(low=0.75, high=0.95)
-        min_corr = 0.90
+        min_corr = 0.80
         max_corr = np.random.uniform(low=0.05, high=0.25)
-        max_corr = 0.10
+        max_corr = 0.20
         h_size = np.random.randint(low=10, high=20)
-        h_size = 20
+        h_size = 40
         w_size = np.random.randint(low=10, high=100)
-        w_size = 40
+        w_size = 80
         rnd_norms = False
         # eps = np.random.uniform(low=0.0, high=0.25)
-        eps = 0.0
-        gen_M = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
-                                                min_intra_corr=min_corr, max_inter_corr=max_corr, epsilon=eps,
-                                                random_norms=rnd_norms)
+        eps = 0
+        gen_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
+                                                         min_intra_corr=min_corr, max_inter_corr=max_corr, epsilon=eps,
+                                                         random_norms=rnd_norms)
         imp_nmf_proxy = imp.Imputer(method="nmf.proxy",
                                     params={"ncomp": 3,
                                             "nblocks": 1,
                                             "nfill_iters": 0})
 
+        imp_mean = imp.Imputer(method="mean")
+
+        imp_nmf_proxy_mean_first = imp.Imputer(method="nmf.proxy",
+                                               params={"ncomp": 3,
+                                                       "nblocks": 1,
+                                                       "nfill_iters": 0,
+                                                       "prefill": "mean"})
+
         imp_nmf_proxy_pgrad = imp.Imputer(method="nmf.proxy",
                                           params={"ncomp": 3,
                                                   "nblocks": 1,
                                                   "use_hals": False,
                                                   "nfill_iters": 0})
 
-        imputers = [[imp_nmf_proxy, None],
-                    [imp_nmf_proxy_pgrad, None]]
+        imputers = [[imp_mean, None],
+                    [imp_nmf_proxy, None],
+                    [imp_nmf_proxy_mean_first, None]]
         imp_name = "RandomBlockMatrices_2"
         imp_tester = imp.ImputerTester(mat=gen_M, name=f"{imp_name}_nc{nb_clusters}",
                                        imputer=imp_nmf_proxy, ref_clst=None,
                                        clst=None, err_func="MSE")
         for imp in imputers:
-            for nc in range(5, 20):
+            for nc in range(1, 20):
                 imputer = imp[0]
                 imputer.set_ncomp(nc)
                 imp_tester.set_imputer(imputer)
                 # imp_tester.run([0.05, 0.10, 0.25, 0.4], ntrials=20)
-                imp_tester.run([0.05], ntrials=1)
+                imp_tester.run([0.01, 0.05, 0.10, 0.15], ntrials=10)
 
         imp_tester.output_results(out_data_path)
 
